@@ -32,6 +32,19 @@ def request_accesstoken(acc: str, pwd: str) -> str:
         return accessToken
 
 
+def request_accesstoken_pc(acc: str, pwd: str) -> str:
+    # 请求accesstooke函数
+    url = "http://bms.microc.cn/shopguide/api/auth/logonweb"
+    data = {}
+    data["loginName"] = acc
+    data["password"] = pwd
+    data["version"] = "1"
+    response = requests.get(url, data)
+    if response.status_code == 200:
+        accessToken = response.json().get("accessToken")
+        return accessToken
+
+
 class base:
     def __init__(self, token, app_secret=None):
         """[summary]
